enum VidUsUnit {
  None,
  percent,
  fraction,
  cm,
  mm,
  um,
  inch,
  ft,
  s,
  minute,
  hour,
  day,
  week,
  week_day,
  Tick,
  msec,
  degree,
  radian,
  g,
  mg,
  ng,
  kg,
  oz,
  lb,
  cm2,
  mm2,
  m2,
  cm3,
  mm3,
  ml,
  L,
  mil,
  cms,
  mms,
  ms,
  cms2,
  mms2,
  cm3s,
  mls,
  mlmin,
  Lmin,
  gcm3,
  gml,
  ngml,
  mmHg,

  mV,
  Hz,
  KHz,

  /// <summary>
  ///  beats per minute
  /// </summary>
  HR,

  //SI
  cm3m2,
  mlm2,

  //CI
  cm3sm2,
  mlsm2,
  cm3minm2,
  mlminm2,
  Lminm2,
  mlmincm2,

  /// <summary>
  /// MVCF:mean velocity of circumferential fiber shortening
  /// </summary>
  circs,

  //CO
  mlbeat,

  mm2pa,

  d1mpa,

  kpa,

  mmHgs,

  gm2,

  /// AVA Index
  cm2m2
}

class VidUsUnitMap {
  //将单位值转换为单位
  static VidUsUnit getUnit(int unitValue) {
    switch (unitValue) {
      case 0:
        return VidUsUnit.None;
      case 1:
        return VidUsUnit.percent;
      case 2:
        return VidUsUnit.fraction;
      case 10:
        return VidUsUnit.cm;
      case 11:
        return VidUsUnit.mm;
      case 12:
        return VidUsUnit.inch;
      case 13:
        return VidUsUnit.ft;
      case 14:
        return VidUsUnit.um;
      case 20:
        return VidUsUnit.s;
      case 21:
        return VidUsUnit.minute;
      case 22:
        return VidUsUnit.hour;
      case 23:
        return VidUsUnit.day;
      case 24:
        return VidUsUnit.week;
      case 25:
        return VidUsUnit.week_day;
      case 26:
        return VidUsUnit.Tick;
      case 27:
        return VidUsUnit.msec;
      case 30:
        return VidUsUnit.degree;
      case 31:
        return VidUsUnit.radian;
      case 40:
        return VidUsUnit.g;
      case 41:
        return VidUsUnit.mg;
      case 42:
        return VidUsUnit.ng;
      case 43:
        return VidUsUnit.kg;
      case 44:
        return VidUsUnit.oz;
      case 45:
        return VidUsUnit.lb;
      case 50:
        return VidUsUnit.cm2;
      case 51:
        return VidUsUnit.mm2;
      case 52:
        return VidUsUnit.m2;
      case 60:
        return VidUsUnit.cm3;
      case 61:
        return VidUsUnit.mm3;
      case 62:
        return VidUsUnit.ml;
      case 63:
        return VidUsUnit.L;
      case 64:
        return VidUsUnit.mil;
      case 70:
        return VidUsUnit.cms;
      case 71:
        return VidUsUnit.mms;
      case 72:
        return VidUsUnit.ms;
      case 80:
        return VidUsUnit.cms2;
      case 81:
        return VidUsUnit.mms2;
      case 90:
        return VidUsUnit.cm3s;
      case 91:
        return VidUsUnit.mls;
      case 92:
        return VidUsUnit.mlmin;
      case 93:
        return VidUsUnit.Lmin;
      case 100:
        return VidUsUnit.gcm3;
      case 101:
        return VidUsUnit.gml;
      case 102:
        return VidUsUnit.ngml;
      case 110:
        return VidUsUnit.mmHg;
      case 120:
        return VidUsUnit.mV;
      case 130:
        return VidUsUnit.Hz;
      case 131:
        return VidUsUnit.KHz;
      case 132:
        return VidUsUnit.HR;
      case 140:
        return VidUsUnit.cm3m2;
      case 141:
        return VidUsUnit.mlm2;
      case 150:
        return VidUsUnit.cm3sm2;
      case 151:
        return VidUsUnit.mlsm2;
      case 153:
        return VidUsUnit.cm3minm2;
      case 154:
        return VidUsUnit.mlminm2;
      case 155:
        return VidUsUnit.Lminm2;
      case 156:
        return VidUsUnit.mlmincm2;
      case 160:
        return VidUsUnit.circs;
      case 170:
        return VidUsUnit.mlbeat;
      case 180:
        return VidUsUnit.mm2pa;
      case 181:
        return VidUsUnit.d1mpa;
      case 182:
        return VidUsUnit.kpa;
      case 190:
        return VidUsUnit.mmHgs;
      case 200:
        return VidUsUnit.gm2;
      case 210:
        return VidUsUnit.cm2m2;
      default:
        throw new FormatException('Not supported unit value $unitValue}');
    }
  }

  //将单位转换为单位值
  static int getUnitValue(VidUsUnit unit) {
    switch (unit) {
      case VidUsUnit.None:
        return 0;
      case VidUsUnit.percent:
        return 1;
      case VidUsUnit.fraction:
        return 2;
      case VidUsUnit.cm:
        return 10;
      case VidUsUnit.mm:
        return 11;
      case VidUsUnit.inch:
        return 12;
      case VidUsUnit.ft:
        return 13;
      case VidUsUnit.s:
        return 20;
      case VidUsUnit.minute:
        return 21;
      case VidUsUnit.hour:
        return 22;
      case VidUsUnit.day:
        return 23;
      case VidUsUnit.week:
        return 24;
      case VidUsUnit.week_day:
        return 25;
      case VidUsUnit.Tick:
        return 26;
      case VidUsUnit.msec:
        return 27;
      case VidUsUnit.degree:
        return 30;
      case VidUsUnit.radian:
        return 31;
      case VidUsUnit.g:
        return 40;
      case VidUsUnit.mg:
        return 41;
      case VidUsUnit.ng:
        return 42;
      case VidUsUnit.kg:
        return 43;
      case VidUsUnit.oz:
        return 44;
      case VidUsUnit.lb:
        return 45;
      case VidUsUnit.cm2:
        return 50;
      case VidUsUnit.mm2:
        return 51;
      case VidUsUnit.m2:
        return 52;
      case VidUsUnit.cm3:
        return 60;
      case VidUsUnit.mm3:
        return 61;
      case VidUsUnit.ml:
        return 62;
      case VidUsUnit.L:
        return 63;
      case VidUsUnit.mil:
        return 64;
      case VidUsUnit.cms:
        return 70;
      case VidUsUnit.mms:
        return 71;
      case VidUsUnit.ms:
        return 72;
      case VidUsUnit.cms2:
        return 80;
      case VidUsUnit.mms2:
        return 81;
      case VidUsUnit.cm3s:
        return 90;
      case VidUsUnit.mls:
        return 91;
      case VidUsUnit.mlmin:
        return 92;
      case VidUsUnit.Lmin:
        return 93;
      case VidUsUnit.gcm3:
        return 100;
      case VidUsUnit.gml:
        return 101;
      case VidUsUnit.ngml:
        return 102;
      case VidUsUnit.mmHg:
        return 110;
      case VidUsUnit.mV:
        return 120;
      case VidUsUnit.Hz:
        return 130;
      case VidUsUnit.KHz:
        return 131;
      case VidUsUnit.HR:
        return 132;
      case VidUsUnit.cm3m2:
        return 140;
      case VidUsUnit.mlm2:
        return 141;
      case VidUsUnit.cm3sm2:
        return 150;
      case VidUsUnit.mlsm2:
        return 151;
      case VidUsUnit.cm3minm2:
        return 153;
      case VidUsUnit.mlminm2:
        return 154;
      case VidUsUnit.Lminm2:
        return 155;
      case VidUsUnit.mlmincm2:
        return 156;
      case VidUsUnit.circs:
        return 160;
      case VidUsUnit.mlbeat:
        return 170;
      case VidUsUnit.mm2pa:
        return 180;
      case VidUsUnit.d1mpa:
        return 181;
      case VidUsUnit.kpa:
        return 182;
      case VidUsUnit.mmHgs:
        return 190;
      case VidUsUnit.gm2:
        return 200;
      case VidUsUnit.cm2m2:
        return 210;
      default:
        throw new FormatException('Not supported unit $unit}');
    }
  }
}
